@@ -1,6 +1,6 @@
 package Calendar::Plugin::Renderer::SVG::Page;
 
-$Calendar::Plugin::Renderer::SVG::Page::VERSION   = '0.13';
+$Calendar::Plugin::Renderer::SVG::Page::VERSION   = '0.14';
 $Calendar::Plugin::Renderer::SVG::Page::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Calendar::Plugin::Renderer::SVG::Page - Interface to 'page' of calendar in SVG f
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
@@ -17,7 +17,7 @@ use 5.006;
 use Data::Dumper;
 
 use Moo;
-use namespace::clean;
+use namespace::autoclean;
 
 has 'width'       => (is => 'ro', required => 1);
 has 'width_unit'  => (is => 'ro', required => 1);
